package jp.programmingmat.www.atfskscroll;

import android.view.View;
import android.view.MotionEvent;
import android.content.Context;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.Path;

/*
	タッチ操作ソフトパッド
*/
public class SoftPad extends View {

	private Paint bg_paint = null;
	private Paint active_paint = null;

	public int pad_active = 0;

	private Path path_up = new Path();
	private Path path_right = new Path();
	private Path path_down = new Path();
	private Path path_left = new Path();

	public static final int PADACTIVE_UP = 1;
	public static final int PADACTIVE_RIGHT = 2;
	public static final int PADACTIVE_DOWN = 4;
	public static final int PADACTIVE_LEFT = 8;

	public SoftPad(Context context) {

		super(context);

		// クリック受け入れ設定
		setClickable(true);

		// 背景色を設定
		bg_paint = new Paint();
		bg_paint.setColor(0xffcccccc);

		// 押下状態の塗りつぶし色を設定
		active_paint = new Paint();
		active_paint.setColor(0xff808080);

	}

	@Override
	public boolean onTouchEvent(MotionEvent e) {

		// タッチ時の状態に応じて処理
		switch(e.getAction()) {

		// タッチ状態
		case MotionEvent.ACTION_DOWN:
		case MotionEvent.ACTION_MOVE:

			// 現在位置に応じて押下状態を設定
			if (e.getX() < 0 || e.getX() > getWidth() || e.getY() < 0 || e.getY() > getHeight()) {
				pad_active = 0;
			} else {

				if (e.getX() > e.getY()) {
					if (e.getX() < getHeight() - e.getY()) {
						pad_active = PADACTIVE_UP;
					} else {
						pad_active = PADACTIVE_RIGHT;
					}
				}

				if (e.getX() <= e.getY()) {
					if (e.getX() < getHeight() - e.getY()) {
						pad_active = PADACTIVE_LEFT;
					} else {
						pad_active = PADACTIVE_DOWN;
					}
				}
				
			}

			invalidate();

			return true;

		// タッチ終了
		case MotionEvent.ACTION_UP:
		case MotionEvent.ACTION_CANCEL:

			// 押下状態を解除
			pad_active = 0;

			invalidate();

			return true;

		}

		return false;

	}

	@Override
	protected void onSizeChanged(int w, int h, int oldw, int oldh) {

		// 上状態描画用パスを作成
		path_up.moveTo(0, 0);
		path_up.lineTo(getWidth() / 2, getHeight() / 2);
		path_up.lineTo(getWidth() - 1, 0);
		path_up.close();

		// 右状態描画用パスを作成
		path_right.moveTo(getWidth() - 1, 0);
		path_right.lineTo(getWidth() / 2, getHeight() / 2);
		path_right.lineTo(getWidth() - 1, getHeight() - 1);
		path_right.close();

		// 下状態描画用パスを作成
		path_down.moveTo(getWidth() - 1, getHeight() - 1);
		path_down.lineTo(getWidth() / 2, getHeight() / 2);
		path_down.lineTo(0, getHeight() - 1);
		path_down.close();

		// 左状態描画用パスを作成
		path_left.moveTo(0, 0);
		path_left.lineTo(getWidth() / 2, getHeight() / 2);
		path_left.lineTo(0, getHeight() - 1);
		path_left.close();

	}

	@Override
	protected void onDraw(Canvas cv) {

		// パッド全体を背景色で塗りつぶす
		cv.drawRect(0, 0, getWidth(), getHeight(), bg_paint);

		// 上状態
		if ((pad_active & PADACTIVE_UP) != 0) {
			cv.drawPath(path_up, active_paint);
		}

		// 右状態
		if ((pad_active & PADACTIVE_RIGHT) != 0) {
			cv.drawPath(path_right, active_paint);
		}

		// 下状態
		if ((pad_active & PADACTIVE_DOWN) != 0) {
			cv.drawPath(path_down, active_paint);
		}

		// 左状態
		if ((pad_active & PADACTIVE_LEFT) != 0) {
			cv.drawPath(path_left, active_paint);
		}

	}

}